summaryrefslogtreecommitdiffstats
path: root/src/ChunkMap.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ChunkMap.h')
-rw-r--r--src/ChunkMap.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ChunkMap.h b/src/ChunkMap.h
index 611f08cc9..578c49b8a 100644
--- a/src/ChunkMap.h
+++ b/src/ChunkMap.h
@@ -102,8 +102,8 @@ public:
If the chunk is invalid, the operation is ignored silently. */
void FastSetBlock(Vector3i a_BlockPos, BLOCKTYPE a_BlockType, NIBBLETYPE a_BlockMeta);
- /** Makes the specified player collect all the pickups around them. */
- void CollectPickupsByPlayer(cPlayer & a_Player);
+ /** Makes the specified entity collect all the pickups around them. */
+ void CollectPickupsByEntity(cEntity & a_Entity);
BLOCKTYPE GetBlock (Vector3i a_BlockPos) const;
NIBBLETYPE GetBlockMeta (Vector3i a_BlockPos) const;